@@ -32,7 +32,7 @@ class Event(object):
             returned["time"] = None
             returned["madechatmod"] = True
         elif connection["event"] == "ban":
-            returned["user"] = [connection["data"]["attrs"]["kicedUserName"],
+            returned["user"] = [connection["data"]["attrs"]["kickedUserName"],
                                 connection["data"]["attrs"]["moderatorName"]]
             returned["text"] = None
             returned["status"] = None
@@ -57,7 +57,7 @@ class Event(object):
             returned["time"] = None
             returned["madechatmod"] = False
         elif connection["event"] == "part":
-            returned["user"] = None
+            returned["user"] = connect["data"]["attrs"][""]
             returned["text"] = None
             returned["status"] = None
             returned["time"] = None
